@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "notmuch-maildir" "1.3.2"
+(define-package "notmuch-maildir" "20251101.2053"
   "Display maildirs as a tree."
   '((emacs   "29.1")
     (compat  "30.1")
-    (notmuch "0.39"))
+    (notmuch "0.38"))
   :url "https://github.com/tarsius/notmuch-maildir"
-  :commit "ef3952c785cc4bc41366d798bff5edad1a945553"
-  :revdesc "v1.3.2-0-gef3952c785cc"
+  :commit "f4982d49d05d3b76db55462ec0f7cfee35f92d20"
+  :revdesc "f4982d49d05d"
   :keywords '("mail")
   :authors '(("Jonas Bernoulli" . "emacs.notmuch-maildir@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.notmuch-maildir@jonas.bernoulli.dev")))
